@@ -1,6 +1,5 @@
 from ai_openchat.openai import AsyncOpenAI
-from . import base
-
+from ai_openchat import base
 
 __all__ = (
     'AsyncOpenAI',
